@@ -1,11 +1,11 @@
 import getpass
-QRaAr=object
-QRaAb=staticmethod
-QRaAH=False
-QRaAK=Exception
-QRaAz=None
-QRaAT=input
-QRaAp=list
+syleD=object
+sylek=staticmethod
+syled=False
+syleq=Exception
+syleO=None
+syleF=input
+sylen=list
 import json
 import logging
 import sys
@@ -13,29 +13,29 @@ from localstack.config import CONFIG_FILE_PATH,load_config_file
 from localstack.constants import API_ENDPOINT
 from localstack.utils.common import load_file,safe_requests,save_file,to_str
 LOG=logging.getLogger(__name__)
-class AuthProvider(QRaAr):
- @QRaAb
+class AuthProvider(syleD):
+ @sylek
  def name():
   raise
  def get_or_create_token(self,username,password,headers):
   pass
  def get_user_for_token(self,token):
   pass
- @QRaAb
+ @sylek
  def providers():
   return{c.name():c for c in AuthProvider.__subclasses__()}
- @QRaAb
- def get(provider,raise_error=QRaAH):
+ @sylek
+ def get(provider,raise_error=syled):
   provider_class=AuthProvider.providers().get(provider)
   if not provider_class:
    msg='Unable to find auth provider class "%s"'%provider
    LOG.warning(msg)
    if raise_error:
-    raise QRaAK(msg)
-   return QRaAz
+    raise syleq(msg)
+   return syleO
   return provider_class()
 class AuthProviderInternal(AuthProvider):
- @QRaAb
+ @sylek
  def name():
   return "internal"
  def get_or_create_token(self,username,password,headers):
@@ -46,28 +46,28 @@ class AuthProviderInternal(AuthProvider):
   try:
    result=json.loads(to_str(response.content or "{}"))
    return result["token"]
-  except QRaAK:
+  except syleq:
    pass
  def read_credentials(self,username):
   print("Please provide your login credentials below")
   if not username:
    sys.stdout.write("Username: ")
    sys.stdout.flush()
-   username=QRaAT()
+   username=syleF()
   password=getpass.getpass()
   return username,password,{}
  def get_user_for_token(self,token):
-  raise QRaAK("Not implemented")
-def login(provider,username=QRaAz):
+  raise syleq("Not implemented")
+def login(provider,username=syleO):
  auth_provider=AuthProvider.get(provider)
  if not auth_provider:
-  providers=QRaAp(AuthProvider.providers().keys())
-  raise QRaAK('Unknown provider "%s", should be one of %s'%(provider,providers))
+  providers=sylen(AuthProvider.providers().keys())
+  raise syleq('Unknown provider "%s", should be one of %s'%(provider,providers))
  username,password,headers=auth_provider.read_credentials(username)
  print("Verifying credentials ... (this may take a few moments)")
  token=auth_provider.get_or_create_token(username,password,headers)
  if not token:
-  raise QRaAK("Unable to verify login credentials - please try again")
+  raise syleq("Unable to verify login credentials - please try again")
  configs=load_config_file()
  configs["login"]={"provider":provider,"username":username,"token":token}
  save_file(CONFIG_FILE_PATH,json.dumps(configs))
