@@ -1,12 +1,12 @@
 import base64
-bwlFC=True
-bwlFE=Exception
-bwlFu=False
-bwlFj=str
-bwlFL=len
-bwlFV=int
-bwlFy=range
-bwlFG=object
+mOblp=True
+mOblQ=Exception
+mOblV=False
+mOblM=str
+mObls=len
+mOblX=int
+mOblu=range
+mOblP=object
 import glob
 import json
 import logging
@@ -16,40 +16,40 @@ import sys
 import traceback
 import pyaes
 from localstack import config as localstack_config
+from localstack.constants import ENV_PRO_ACTIVATED
 from localstack.utils.common import load_file,md5,now_utc,parallelize
 from localstack.utils.common import safe_requests as requests
 from localstack.utils.common import save_file,str_insert,str_remove,to_bytes,to_str
-from localstack_ext import config
+from localstack_ext import __version__,config
 from localstack_ext.config import PROTECTED_FOLDERS,ROOT_FOLDER
-from localstack_ext.constants import ENV_PRO_ACTIVATED,VERSION
 ENV_PREPARED={}
 MAX_KEY_CACHE_DURATION_SECS=60*60*24
 LOG=logging.getLogger(__name__)
 ENV_LOCALSTACK_API_KEY="LOCALSTACK_API_KEY"
-def read_api_key(raise_if_missing=bwlFC):
+def read_api_key(raise_if_missing=mOblp):
  key=(os.environ.get(ENV_LOCALSTACK_API_KEY)or "").strip()
  if not key and raise_if_missing:
-  raise bwlFE("Unable to retrieve API key. Please configure $%s in your environment"%ENV_LOCALSTACK_API_KEY)
+  raise mOblQ("Unable to retrieve API key. Please configure $%s in your environment"%ENV_LOCALSTACK_API_KEY)
  return key
 def fetch_key():
  api_key=read_api_key()
  if api_key=="test":
   return "test"
- data={"api_key":api_key,"version":VERSION}
+ data={"api_key":api_key,"version":__version__}
  try:
   logging.getLogger("py.warnings").setLevel(logging.ERROR)
-  result=requests.post("%s/activate"%config.API_URL,json.dumps(data),verify=bwlFu)
+  result=requests.post("%s/activate"%config.API_URL,json.dumps(data),verify=mOblV)
   if result.status_code>=400:
    content=result.content
    content_type=result.headers.get("Content-Type")
-   raise bwlFE('Received error activating key (code %s): ctype "%s" - %s'%(result.status_code,content_type,content))
+   raise mOblQ('Received error activating key (code %s): ctype "%s" - %s'%(result.status_code,content_type,content))
   key_base64=json.loads(to_str(result.content))["key"]
   cache_key_locally(api_key,key_base64)
- except bwlFE as e:
+ except mOblQ as e:
   if log_license_issues():
-   api_key=bwlFj(api_key_configured()or "")
+   api_key=mOblM(api_key_configured()or "")
    api_key_prefix=api_key[:3]
-   LOG.warning('Error activating API key "%s..."(%s): %s %s'%(api_key_prefix,bwlFL(api_key),e,traceback.format_exc()))
+   LOG.warning('Error activating API key "%s..."(%s): %s %s'%(api_key_prefix,mObls(api_key),e,traceback.format_exc()))
   key_base64=load_cached_key(api_key)
  finally:
   logging.getLogger("py.warnings").setLevel(logging.WARNING)
@@ -57,25 +57,25 @@ def fetch_key():
  return decoded_key
 def cache_key_locally(api_key,key_b64):
  configs=localstack_config.load_config_file()
- timestamp=bwlFj(bwlFV(now_utc()))
+ timestamp=mOblM(mOblX(now_utc()))
  key_raw=to_str(base64.b64decode(key_b64))
- for i in bwlFy(bwlFL(timestamp)):
+ for i in mOblu(mObls(timestamp)):
   key_raw=str_insert(key_raw,i*2,timestamp[i])
  key_b64=to_str(base64.b64encode(to_bytes(key_raw)))
- configs["cached_key"]={"timestamp":bwlFV(timestamp),"key_hash":md5(api_key),"key":key_b64}
+ configs["cached_key"]={"timestamp":mOblX(timestamp),"key_hash":md5(api_key),"key":key_b64}
  save_file(localstack_config.CONFIG_FILE_PATH,json.dumps(configs))
  return configs
 def load_cached_key(api_key):
  configs=localstack_config.load_config_file()
  cached_key=configs["cached_key"]
  if cached_key.get("key_hash")!=md5(api_key):
-  raise bwlFE("Cached key was created for a different API key")
+  raise mOblQ("Cached key was created for a different API key")
  now=now_utc()
  if(now-cached_key["timestamp"])>MAX_KEY_CACHE_DURATION_SECS:
-  raise bwlFE("Cached key expired")
- timestamp=bwlFj(cached_key["timestamp"])
+  raise mOblQ("Cached key expired")
+ timestamp=mOblM(cached_key["timestamp"])
  key_raw=to_str(base64.b64decode(cached_key["key"]))
- for i in bwlFy(bwlFL(timestamp)):
+ for i in mOblu(mObls(timestamp)):
   assert key_raw[i]==timestamp[i]
   key_raw=str_remove(key_raw,i)
  key_b64=to_str(base64.b64encode(to_bytes(key_raw)))
@@ -114,25 +114,25 @@ def cleanup_environment():
       if os.path.exists(delete_file):
        os.remove(delete_file)
 def prepare_environment():
- class OnClose(bwlFG):
+ class OnClose(mOblP):
   def __exit__(self,*args,**kwargs):
    if not ENV_PREPARED.get("finalized"):
     cleanup_environment()
-   ENV_PREPARED["finalized"]=bwlFC
+   ENV_PREPARED["finalized"]=mOblp
   def __enter__(self,*args,**kwargs):
    pass
  if not ENV_PREPARED.get("finalized"):
   try:
    key=fetch_key()
    if not key:
-    raise bwlFE("Unable to fetch and validate API key from environment")
+    raise mOblQ("Unable to fetch and validate API key from environment")
    if key!="test":
     decrypt_files(key)
     LOG.info("Successfully activated API key")
    else:
     LOG.info("Using test API key")
    os.environ[ENV_PRO_ACTIVATED]="1"
-  except bwlFE as e:
+  except mOblQ as e:
    if log_license_issues():
     LOG.warning("Unable to activate API key: %s %s"%(e,traceback.format_exc()))
    if config.REQUIRE_PRO:
@@ -142,12 +142,18 @@ def prepare_environment():
 def log_license_issues():
  return api_key_configured()and localstack_config.is_env_true("LOG_LICENSE_ISSUES")
 def api_key_configured():
- return read_api_key(raise_if_missing=bwlFu)
+ return read_api_key(raise_if_missing=mOblV)
+def is_logged_in():
+ configs=localstack_config.load_config_file()
+ login_info=configs.get("login")
+ if not login_info:
+  return mOblV
+ return mOblp
 def get_auth_headers():
  configs=localstack_config.load_config_file()
  login_info=configs.get("login")
  if not login_info:
-  raise bwlFE("Please log in first")
+  raise mOblQ("Please log in first")
  auth_token=login_info["token"]
  if not auth_token.startswith("%s "%login_info["provider"]):
   auth_token="%s %s"%(login_info["provider"],auth_token)
