@@ -1,12 +1,13 @@
 import logging
-NKjmr=Exception
-NKjmc=any
-NKjmM=str
-NKjmA=None
-NKjmX=False
-NKjml=bool
-NKjmy=True
+IABiO=Exception
+IABiX=any
+IABik=str
+IABiv=None
+IABiD=False
+IABir=bool
+IABix=True
 import os
+import traceback
 from localstack import config as localstack_config
 from localstack.constants import LOCALSTACK_INFRA_PROCESS,LOCALSTACK_WEB_PROCESS,TRUE_STRINGS
 from localstack.utils import common
@@ -29,14 +30,14 @@ def register_localstack_plugins():
   try:
    from localstack_ext.services import dns_server
    dns_server.setup_network_configuration()
-  except NKjmr:
+  except IABiO:
    return
   if is_infra_process:
    load_plugin_files()
   try:
    if is_api_key_configured and not is_infra_process and is_api_enabled("ec2"):
     local_daemon.start_in_background()
-  except NKjmr as e:
+  except IABiO as e:
    LOG.warning("Unable to start local daemon process: %s"%e)
   if is_api_key_configured:
    if os.environ.get("EDGE_PORT")and not localstack_config.EDGE_PORT_HTTP:
@@ -45,6 +46,7 @@ def register_localstack_plugins():
     port=localstack_config.EDGE_PORT
     localstack_config.EDGE_PORT=443
     localstack_config.EDGE_PORT_HTTP=port
+ API_DEPENDENCIES["amplify"]=["s3","appsync","cognito-idp","cognito-identity"]
  API_DEPENDENCIES["apigateway"]=["apigatewayv2"]
  API_DEPENDENCIES["athena"]=["emr"]
  API_DEPENDENCIES["docdb"]=["rds"]
@@ -67,7 +69,7 @@ def register_localstack_plugins():
    docker_flags+=["-p {a}:{p}:{p}".format(a=config_ext.DNS_ADDRESS,p=dns_server.DNS_PORT)]
   if not common.is_port_open(dns_server.DNS_PORT,protocols="udp"):
    docker_flags+=["-p {a}:{p}:{p}/udp".format(a=config_ext.DNS_ADDRESS,p=dns_server.DNS_PORT)]
- if NKjmc([is_api_enabled(api)for api in EXTERNAL_PORT_APIS]):
+ if IABiX([is_api_enabled(api)for api in EXTERNAL_PORT_APIS]):
   docker_flags+=["-p {start}-{end}:{start}-{end}".format(start=config_ext.SERVICE_INSTANCES_PORTS_START,end=config_ext.SERVICE_INSTANCES_PORTS_END)]
  if is_api_enabled("eks"):
   kube_config=os.path.expanduser("~/.kube/config")
@@ -86,6 +88,7 @@ def load_plugin_files():
   from localstack_ext.services import edge
   from localstack_ext.services.amplify import amplify_starter
   from localstack_ext.services.apigateway import apigateway_extended
+  from localstack_ext.services.appconfig import appconfig_starter
   from localstack_ext.services.applicationautoscaling import(applicationautoscaling_listener,applicationautoscaling_starter)
   from localstack_ext.services.appsync import appsync_starter
   from localstack_ext.services.athena import athena_starter
@@ -102,6 +105,7 @@ def load_plugin_files():
   from localstack_ext.services.costexplorer import costexplorer_starter
   from localstack_ext.services.docdb import docdb_api
   from localstack_ext.services.dynamodb import dynamodb_extended
+  from localstack_ext.services.ec2 import ec2_listener,ec2_starter
   from localstack_ext.services.ecr import ecr_listener,ecr_starter
   from localstack_ext.services.ecs import ecs_listener,ecs_starter
   from localstack_ext.services.efs import efs_api
@@ -117,7 +121,7 @@ def load_plugin_files():
   from localstack_ext.services.iot import iot_listener,iot_starter
   from localstack_ext.services.kafka import kafka_starter
   from localstack_ext.services.kinesisanalytics import kinesis_analytics_api
-  from localstack_ext.services.kms import kms_listener,kms_starter
+  from localstack_ext.services.lakeformation import lakeformation_api
   from localstack_ext.services.mediastore import mediastore_starter
   from localstack_ext.services.neptune import neptune_api
   from localstack_ext.services.organizations import organizations_starter
@@ -139,8 +143,8 @@ def load_plugin_files():
   from localstack_ext.services.transfer import transfer_starter
   from localstack_ext.services.xray import xray_listener,xray_starter
   from localstack_ext.utils import persistence as persistence_ext
-  from localstack_ext.utils.aws import aws_utils
   register_plugin(Plugin("amplify",start=amplify_starter.start_amplify))
+  register_plugin(Plugin("appconfig",start=appconfig_starter.start_appconfig))
   register_plugin(Plugin("application-autoscaling",start=applicationautoscaling_starter.start_applicationautoscaling,listener=applicationautoscaling_listener.UPDATE_APPLICATION_AUTOSCALING))
   register_plugin(Plugin("appsync",start=appsync_starter.start_appsync))
   register_plugin(Plugin("athena",start=athena_starter.start_athena))
@@ -148,20 +152,21 @@ def load_plugin_files():
   register_plugin(Plugin("azure",start=azure_starter.start_azure))
   register_plugin(Plugin("backup",start=backup_starter.start_backup))
   register_plugin(Plugin("batch",start=batch_starter.start_batch,listener=batch_listener.UPDATE_BATCH))
+  register_plugin(Plugin("ce",start=costexplorer_starter.start_costexplorer))
   register_plugin(Plugin("cloudfront",start=cloudfront_starter.start_cloudfront))
   register_plugin(Plugin("cloudtrail",start=cloudtrail_starter.start_cloudtrail))
   register_plugin(Plugin("codecommit",start=codecommit_starter.start_codecommit,listener=codecommit_listener.UPDATE_CODECOMMIT))
   register_plugin(Plugin("cognito-identity",start=cognito_starter.start_cognito_identity,listener=cognito_identity_api.UPDATE_COGNITO_IDENTITY))
   register_plugin(Plugin("cognito-idp",start=cognito_starter.start_cognito_idp,listener=cognito_idp_api.UPDATE_COGNITO))
-  register_plugin(Plugin("ce",start=costexplorer_starter.start_costexplorer))
   register_plugin(Plugin("docdb",start=docdb_api.start_docdb))
+  register_plugin(Plugin("ec2",start=ec2_starter.start_ec2,listener=ec2_listener.UPDATE_EC2,priority=10))
+  register_plugin(Plugin("ecr",start=ecr_starter.start_ecr,listener=ecr_listener.UPDATE_ECR))
+  register_plugin(Plugin("ecs",start=ecs_starter.start_ecs,listener=ecs_listener.UPDATE_ECS))
   register_plugin(Plugin("efs",start=efs_api.start_efs))
   register_plugin(Plugin("elasticache",start=elasticache_starter.start_elasticache))
   register_plugin(Plugin("elasticbeanstalk",start=elasticbeanstalk_starter.start_elasticbeanstalk))
   register_plugin(Plugin("elb",start=elb_starter.start_elb,listener=elb_listener.UPDATE_ELB))
   register_plugin(Plugin("elbv2",start=elb_starter.start_elbv2,listener=elb_listener.UPDATE_ELB))
-  register_plugin(Plugin("ecr",start=ecr_starter.start_ecr,listener=ecr_listener.UPDATE_ECR))
-  register_plugin(Plugin("ecs",start=ecs_starter.start_ecs,listener=ecs_listener.UPDATE_ECS))
   register_plugin(Plugin("eks",start=eks_starter.start_eks))
   register_plugin(Plugin("emr",start=emr_starter.start_emr,listener=emr_listener.UPDATE_EMR))
   register_plugin(Plugin("glacier",start=glacier_starter.start_glacier,listener=glacier_listener.UPDATE_GLACIER))
@@ -169,7 +174,7 @@ def load_plugin_files():
   register_plugin(Plugin("iot",start=iot_starter.start_iot,listener=iot_listener.UPDATE_IOT))
   register_plugin(Plugin("kafka",start=kafka_starter.start_kafka))
   register_plugin(Plugin("kinesisanalytics",start=kinesis_analytics_api.start_kinesis_analytics))
-  register_plugin(Plugin("kms",start=kms_starter.start_kms,listener=kms_listener.UPDATE_KMS))
+  register_plugin(Plugin("lakeformation",start=lakeformation_api.start_lakeformation))
   register_plugin(Plugin("mediastore",start=mediastore_starter.start_mediastore))
   register_plugin(Plugin("neptune",start=neptune_api.start_neptune))
   register_plugin(Plugin("organizations",start=organizations_starter.start_organizations))
@@ -198,27 +203,26 @@ def load_plugin_files():
   ses_extended.patch_ses()
   route53_extended.patch_route53()
   dashboard_extended.patch_dashboard()
-  aws_utils.patch_aws_stack()
   edge.patch_start_edge()
   patch_start_infra()
- except NKjmr as e:
-  if "No module named" not in NKjmM(e):
-   print("ERROR: %s"%e)
+ except IABiO as e:
+  if "No module named" not in IABik(e):
+   print("ERROR: %s %s"%(e,traceback.format_exc()))
 def patch_start_infra():
  from localstack.services import infra
  try:
   from localstack_ext.utils.aws.metadata_service import start_metadata_service
- except NKjmr:
-  start_metadata_service=NKjmA
+ except IABiO:
+  start_metadata_service=IABiv
  def do_start_infra(asynchronous,apis,is_in_docker,*args,**kwargs):
   if common.in_docker():
    try:
     start_metadata_service and start_metadata_service()
-   except NKjmr:
+   except IABiO:
     pass
   enforce_before=config_ext.ENFORCE_IAM
   try:
-   config_ext.ENFORCE_IAM=NKjmX
+   config_ext.ENFORCE_IAM=IABiD
    return do_start_infra_orig(asynchronous,apis,is_in_docker,*args,**kwargs)
   finally:
    config_ext.ENFORCE_IAM=enforce_before
@@ -241,9 +245,9 @@ def _setup_logging():
  logging.getLogger("root").setLevel(logging.WARNING)
  logging.getLogger("").setLevel(logging.WARNING)
 def api_key_configured():
- return NKjml(os.environ.get("LOCALSTACK_API_KEY"))
+ return IABir(os.environ.get("LOCALSTACK_API_KEY"))
 def register_localstack_commands():
  if api_key_configured():
   cli.register_commands()
- return NKjmy
+ return IABix
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
